/* 
"Open Borders," RED, April 13
*/
set more off
set linesize 120
log using    miggain11a.log , text replace

scalar million  = 1e6
scalar thousand = 1e3
scalar latest = 2010  // latest year available
/*
Data Sources
*/

* http://pwt.econ.upenn.edu/Downloads/pwt71/pwt71_07262012version.zip
insheet using pwt71_w_country_names.csv , clear
lab var rgdpl2wok "GDP per worker, ppp (PWT7.1, Laspeyres)"

*  189 countries, 61 years each,  11,529 observations

sort isocode
merge m:1 isocode using webcodes.dta ,   keepusing( isocode webcode)
drop _merge

drop if isocode == "CH2"  // China, version 2

merge m:1 isocode using WageRatios.dta , keepusing( isocode R0 R70)
drop _merge
replace R0  = . if year != 1999
replace R70 = . if year != 1999

/*
"Caselli, Francesco and Feyrer, James, "The Marginal Product of Capital", The Quarterly Journal of Economics 122, 2 (2007), pp. 535-568"
data copied from Table 2
(see also Caselli-Ferrer data: http://personal.lse.ac.uk/casellif/data/QJE2006.dta)
*/

merge m:1 isocode using CaselliFeyrerQJE2006Table2.dta , keepusing(isocode Py_Pk alpha_k y96 k)
drop _merge
lab var y96 "GDP per worker" 
lab var k "reproducible capital per worker" 
lab var alpha_k "reproducible capital share" 
lab var  Py_Pk "(final goods price level)/(reproducible capital price level)" 

gen PMPKL2 = Py_Pk *alpha_k *y96/ k

/*
BG labor shares

*/
gen wbcode = isocode
sort wbcode
merge m:1 wbcode using bg2001.dta , keepusing(wbcode  empshare naivesh acosadj imosadj lfadj)
drop if wbcode == "DEU"  // West Germany
drop if wbcode == "BUR"  // Burma=Myanmar not in PWT since 6.0
drop _merge
gen     labshareBG = acosadj
replace labshareBG = imosadj if labshareBG == . & empshare >= .5
replace labshareBG = lfadj   if labshareBG == . & empshare >= .5
replace labshareBG = .       if labshareBG > .95  // a fudge: Nicaragua labor share data just ignored in the BG paper
                                                  // text says any country with empshare > .5 is included: not true
sum    labshareBG if webcode == "us"
scalar labshare_us0 = r(mean)
gen    labshare_us  = labshare_us0


/*
Gollin labor shares
*/

merge m:1 webcode using Gollin.dta
drop if webcode == "re"  // Reunion not in PWT

gen     labshare = labshareBG
replace labshare = labshareGollin2 if labshare == .

gen byte nolabshare = (labshareBG == . & labshareGollin2 == .)

// assume labor shares are equal across countries, for countries with missing labor share data
scalar avlabshare = 2.0/3.0 // Gollin == .675, Bernanke and Gurkaynak = .65
replace labshare = avlabshare  if labshare == .


/*
U.S. GDP deflator
 http://www.bea.gov/newsreleases/national/gdp/gdpnewsrelease.htm,  Table 6,  Implicit price deflators
 http://www.bea.gov/newsreleases/national/gdp/2012/txt/gdp2q12_3rd.txt  SEPTEMBER 27, 2012
*/
scalar GDPdef12Q2r = 115.035/100  // index (2005 = 100)
scalar GDPdef = GDPdef12Q2r

/*
derived variables
*/

replace R0  = 1.0  if webcode == "us" & year == 1999 
replace R0  = 6.13 if webcode == "cn" & year == 1999  // Xiaodong Fan,  June 29, 2012
replace R0  = 1.55 if webcode == "pr" & year == 1999  // Clemens et al Table 9
gen R0i = 1/R0
lab var R0i "Wage Relative to U.S."


//////////////////////////////////////////////////////////////



* drop pos
gen pos = 3 
replace pos =  9 if webcode == "co"
replace pos =  1 if webcode == "cl"
replace pos =  6 if webcode == "gh"
replace pos = 11 if webcode == "pk"
replace pos =  4 if webcode == "vn"

replace pos =  2 if webcode == "np"
replace pos =  2 if webcode == "in"

scatter rgdpl2 R0i if R0i != . & year == 1999 , msym(o ) mcolor(pink) msize(small) mlab( webcode) mlabv(pos) xscale(log) yscale(log) ///
  xlab(.06 .08 .1 .12 .15 .2 .25 .3 .35 .4 .5 to 1.0 , grid) ylab(500 1000 2000 5000 10000 25000 50000 , angle(45) grid)  ///
  xtitle("Wages relative to U.S. (log scale)") ytitle("GDP per person (PPP, $2005, log scale)") title("Relative Wages and GDP per Person, 1999")
graph export "CMPwages2.eps", as(eps) preview(on) replace  

gen popm = pop/1000
lab var popm "Population in millions (PWT7.1)"

gen Re70i = 1/R70
twoway (scatter Re70i R0i if year == 1999 &popm>1 & Re70i < .65 & R0i < .55 , mlabel(webcode)) /// 
   (function y=x, range(0 .55) n(1500) lwidth(medthick)) /// 
   ,ylab(0 .05 .1 to .6, grid) xlab(0 .05 .1 to .55,grid) legend(off) ytitle("Wage Relative to U.S., 70% Selection") ///
  xtitle("Mean Wage Relative to U.S.") title("Selected Wage Differences, 1999")
graph export "WageDiff2.eps", as(eps) preview(on) replace

 gen rgdpl2_us_    =     rgdpl2                  if webcode=="us" // Laspeyres index, derived from "domestic absorbtion"
egen rgdpl2_us     = max(rgdpl2_us_),    by(year)
 gen rgdpl2wok_us_ =     rgdpl2wok               if webcode=="us" // Laspeyres index
egen rgdpl2wok_us  = max(rgdpl2wok_us_), by(year)

gen relwkinc = (labshare*rgdpl2wok)/(labshare_us*rgdpl2wok_us)

drop pos
gen pos = 3 if nolabshare == 0
replace pos = 12 if webcode == "ec" 
replace pos =  2 if webcode == "lk" 
replace pos =  4 if webcode == "bo" 

twoway (scatter relwkinc R0i if year == 1999 &R0i !=. & nolabshare == 0 & webcode != "us" & webcode != "pr" & relwkinc <=R0i, /// 
 mlabel(webcode) mlabv(pos) ylab(.05 .1 to .5, grid)) ///
               (line R0i R0i if year == 1999 &R0i !=. & nolabshare == 0 & webcode != "us" & webcode != "pr" & relwkinc != .) /// 
(scatter relwkinc R0i        if year == 1999 &R0i !=. & nolabshare == 0 & relwkinc > R0i & relwkinc != . & webcode != "pr" , /// 
  mcolor(red) mlabel(webcode) mlabcolor(red) ) , xlab(.08 .1 to .5,grid labsize(small)) legend(off) ///
ytitle("Relative Income per worker (PPP)") title("Relative Wages and Income per Worker")
graph export "\Dropbox\Papers\Gent\Figures\relwageGDPwkr3.eps", as(eps) preview(on) replace

twoway (scatter PMPKL2 R0i if R0i !=. & year == 1999 & relwkinc <=R0i & PMPKL2 != ., mlabel(webcode)), ylab( .03 .04 to .12,grid) xlab(.15 .2 to 1.0,grid) ///
  legend(off) ytitle("MPK") title("Factor Prices")
 graph export "vw2.eps", as(eps) preview(on) replace
 
count if year==latest & rgdpl2 == .
 gen byte frontier3_ = (year==latest &  rgdpl2 > 25000 ) // Korea is a frontier country
egen byte frontier3  = max(frontier3_), by(country)

/*
 This version uses GDP per person above 25000 in 2010
*/
gen byte frontier = frontier3

do EU  // indicator for EU countries

twoway (scatter rgdpl2 popm if year==latest & frontier == 0 & EU == 1, msym(o ) mcolor(magenta) msize(small) mlab( webcode) mlabcolor(magenta)) ///
       (scatter rgdpl2 popm if year==latest & webcode == "pr"         , msym(o ) mcolor(orange)  msize(small) mlab( webcode) mlabcolor(orange)) ///
       (scatter rgdpl2 popm if year==latest & frontier == 1          , msym(o ) mcolor(blue)    msize(small) mlab( webcode ) mlabcolor(blue)) ///
  , xscale(log) yscale(log) legend(off) ///
  xlab(.1 1 10 100 300 ,grid) ylab(10000 25000 50000 100000 150000, angle(45) grid) yline(25000) ///
  xtitle("Population (millions, log scale)") ytitle("GDP per person (PPP, $2005, log scale)") title("GDP per person, Frontier Countries, 2010")
graph export "Frontier5hi.eps", as(eps) preview(on) replace  

count if frontier == 1 & year == latest

replace frontier = 1 if webcode == "pr" 
replace frontier = 1 if EU == 1 

twoway (scatter rgdpl2 popm if year==latest & frontier  == 0 , msym(o ) mcolor(pink)    msize(small) mlab( webcode)) ///
  , xscale(log) yscale(log) legend(off) ///
  xlab(.05 .1 1 10 100 300 1000,grid) ylab(200 300 500 1000 2000 5000 10000 25000, angle(45) grid) yline(25000) ///
  xtitle("Population (millions, log scale)") ytitle("GDP per person (PPP, $2005, log scale)") title("GDP per person, Non-Frontier Countries, 2010")
graph export "Frontier5lo.eps", as(eps) preview(on) replace  

count if frontier == 1 & year == latest

count if rgdpl2wok != . & year == latest


/* 
 Estimate relative wages for countries that are not in the Clemens et al data 
*/ 

gen      rgdp = rgdpl2*pop  // pop is in thousands, so rgdp is in thousands (of 2005 PPP dollars)
lab var  rgdp " rgdpl2*pop"
gen labincome = labshare*rgdp   //  lambda*Y (also in thousands)

gen relgdpl2    = rgdpl2   / rgdpl2_us
gen relgdpl2wok = rgdpl2wok/ rgdpl2wok_us

gen lfpr2 = rgdpl2/rgdpl2wok  // labor force participation rate
gen wkr2  = pop*lfpr2         // labor force

gen byte baddata =      (webcode == "eg") // implausible relative wage data, when compared with real GDP per worker
replace  baddata = 1 if (webcode == "ve")
replace  baddata = 1 if (webcode == "ye")

gen byte include_countries_ = (R0i != . & webcode != "us" & webcode != "pr" & baddata==0 )
egen     include_countries  = max(include_countries_), by(country)

/*
 11 countries have missing data on GDP per worker (so the number of workers is missing)
  Antigua and Barbuda, Dominica, Grenada, Kiribati, Marshall Islands, Micronesia Fed. Sts., 
  Montenegro, Palau, Seychelles, St. Kitts & Nevis
   also Bermuda, a frontier country
 The largest of these is Montenegro (pop = 666,730)
*/

list country webcode rgdpl2 pop if year == latest & rgdpl2wok == ., noobs

sum    lfpr2 if webcode == "me" & year == 2005 // Montenegro
scalar lfpr_me05 = r(mean) 

sum lfpr2 if year == latest [w=pop], detail
sca lfpr_av = r(mean)
sum lfpr2 if year == latest & frontier == 0 [w=pop], detail
sca lfpr_av_f0 = r(mean)

replace wkr2 = lfpr_av   *pop if year == latest & wkr2 == .
replace wkr2 = lfpr_av_f0*pop if year == latest & wkr2 == . & frontier == 0
replace wkr2 = lfpr_me05 *pop if year == latest & webcode == "me"

reg R0i relgdpl2wok if include_countries == 1 & year == 1999 [w=wkr2]  // 40 countries
predict R0ihat

reg R0i relgdpl2 if include_countries == 1 & year == 1999 [w=wkr2]  // 40 countries
predict R0ihat2

gen R0i_res_   = R0i - R0ihat  // defined only for 1999
gen R0i_res2_  = R0i - R0ihat2

egen R0i_res   = max(R0i_res_)  , by(country) // use the 1999 residual for all years (for 40 countries with relative wage data)
egen R0i_res2  = max(R0i_res2_) , by(country)

    gen Roi = R0ihat // wage ratio for workers with the same observed characteristics -- "o" for observed 
replace Roi = R0ihat  + R0i_res if include_countries == 1  // countries that have relative wage data, except for Egypt and Venezuela and Yemen
replace Roi = R0ihat2           if R0ihat == . // 11 countries in 2010 plus Bermuda (a frontier country)
replace Roi = 1.0               if frontier == 1 

gen efflab0    = labincome                 // effective labor with no migration -- wage normalized to 1
gen efflabgain = (1- Roi)^2*labincome/Roi  // effective labor gain due to migration

gen efflab1 = efflab0 + efflabgain
gen efflabg = efflab1/efflab0 

egen wefflab0 = sum(efflab0) if year==latest
egen wefflab1 = sum(efflab1) if year==latest

sum wefflab0
sca wefflab0s = r(mean) // in thousands
sum wefflab1
sca wefflab1s = r(mean)
dis wefflab1s/wefflab0s

gen incwkr_us = labshare_us*rgdpl2wok_us // in dollars (not thousands)
sum incwkr_us if year == latest
scalar incwkr_us_now = r(mean)

dis (thousand*wefflab0s)/incwkr_us_now/million // converted to millions: (thousand*wefflab0s)/incwkr_us_now/million
dis (thousand*wefflab1s)/incwkr_us_now/million // effective supply with migration

sum rgdpl2wok_us if year == latest & webcode == "us"
scalar rgdpl2_us_now = r(mean)
total rgdp if year == latest
matrix Mrgdp = e(b)
scalar wrgdp_now = Mrgdp[1,1]
dis (thousand*wrgdp_now)/rgdpl2_us_now/million // effective labor supply, equal labor shares

sum wkr2 if year == latest & webcode == "us"   // thousands

// ---------------
// Migration Gains
// ---------------

 gen  incwkr_Pnow = GDPdef*labshare*rgdpl2*pop/wkr2 // in current PPP dollars (not thousands)

 gen gainwk_Pnow  = (((1- Roi)^2)/(Roi*2))*incwkr_Pnow
 gen miggain_Pnow = gainwk_Pnow*wkr2
egen wgain_Pnow   = total(miggain_Pnow) if frontier == 0 & year == latest & wkr2 != .
egen wlab_Pnow    = total(wkr2)  	  if frontier == 0 & year == latest & wkr2 != .
sum wgain_Pnow wlab_Pnow
 gen wgainwk_Pnow 	= wgain_Pnow/wlab_Pnow
 sum wgainwk_Pnow

sum  gainwk_Pnow         if frontier == 0 & year == latest & include_countries == 1 [w=wkr2] // Clemens et al data (minus eg, ye, ve)
sca wgainwk_PnowN40s = r(mean)
sum  incwkr_Pnow         if frontier == 0 & year == latest & include_countries == 1 [w=wkr2]
sca wincwkr_PnowN40s = r(mean)
dis wgainwk_PnowN40s/wincwkr_PnowN40s
gen wgainwk_PnowN40 = wgainwk_PnowN40s

sum  gainwk_Pnow            if frontier == 0 & year == latest [w=wkr2]
sca wgainwk_Pnows = r(mean)
sum  incwkr_Pnow            if frontier == 0 & year == latest [w=wkr2]
sca wincwkr_Pnows = r(mean)
dis wgainwk_Pnows/wincwkr_Pnows

gen pos2 = 3 
replace pos2 =  2 if webcode == "bd" 
replace pos2 =  2 if webcode == "pa" 
replace pos2 =  6 if webcode == "bo"
replace pos2 = 11 if webcode == "lk"
replace pos2 =  2 if webcode == "gy"
replace pos2 =  4 if webcode == "pe"
replace pos2 =  4 if webcode == "np"
replace pos2 =  1 if webcode == "gh"

twoway (scatter gainwk_Pnow incwkr_Pnow if year == latest & baddata==0 & frontier == 0  & include_countries == 1, mlab(webcode) mlabv(pos2)) ///
       (line wgainwk_PnowN40 incwkr_Pnow if year == latest & include_countries == 1  & frontier == 0 , lwidth(medthick) ), ///
    xlab(500 2000 4000 to 8000 12000 15000 18000 to 24000,grid angle(45)) ylab(1000 2000 4000 to 8000 10798 15000 18000 to 21000 ,grid angle(45)) /// 
   legend(off) xtitle("Income per Worker") ytitle("Net Gain per Worker (ppp$2012)" ) ///
   title("Open Borders: Net Gains from Migration")
    graph export "GainPop6.eps", as(eps) preview(on) replace

// Appendix Table 1
 gen R0i99_ = R0i if year == 1999
egen R0i99  = max(R0i99_), by(country)
gen rgdpl2wok_Pnow = rgdpl2wok*GDPdef

gen wkr_m = wkr2/thousand  // labor force in millions

list country webcode labshareBG labshareGollin2 R0i99 Roi wkr_m rgdpl2wok_Pnow incwkr_Pnow gainwk_Pnow /// 
     if (include_countries == 1 ) & frontier == 0 & nolabshare == 0 & year==latest, noobs clean

sum                  labshareBG labshareGollin2 R0i99 Roi wkr_m rgdpl2wok_Pnow incwkr_Pnow gainwk_Pnow /// 
    if (include_countries == 1 ) & frontier == 0 & nolabshare == 0 & year==latest                      // unweighted 
sum                  labshareBG labshareGollin2 R0i99 Roi wkr_m rgdpl2wok_Pnow incwkr_Pnow gainwk_Pnow /// 
    if (include_countries == 1 ) & frontier == 0 & nolabshare == 0 & year==latest [w = wkr_m]          //   weighted 

// Appendix Table A2
list country webcode  R0i99 Roi wkr_m rgdpl2wok_Pnow incwkr_Pnow gainwk_Pnow /// 
    if (include_countries == 1 ) & frontier == 0 & nolabshare == 1 & year==latest, noobs clean
 sum                  R0i99 Roi wkr_m rgdpl2wok_Pnow incwkr_Pnow gainwk_Pnow /// 
    if (include_countries == 1 ) & frontier == 0 & nolabshare == 1 & year==latest                      // unweighted 
 sum                  R0i99 Roi wkr_m rgdpl2wok_Pnow incwkr_Pnow gainwk_Pnow /// 
    if (include_countries == 1 ) & frontier == 0 & nolabshare == 1 & year==latest [w = wkr_m]          //   weighted 
	 
save pwt71Oct12, replace

log close
	
